@@ -85,7 +85,7 @@ def list_namespaces():
         silent=True,
     )
     namespaces_list = namespaces.split("\n")
-    return namespaces_list[1:]
+    return namespaces_list
 
 def get_default_namespace(cluster_config, namespace):
     default_namespace = cluster_config.get(namespace, "default")
@@ -198,7 +198,7 @@ class ClusterManager(object):
             default_namespace = self.cluster_config["defaultNamespace"]
             run_cmd(f"kubectl config set-context --current --namespace={default_namespace}")
         else:
-            run_cmd(f"kubectl config set-context --current --namespace=default")
+            run_cmd("kubectl config set-context --current --namespace=default")
 
     def default_namespace_exists(self):
         if "defaultNamespace" in self.cluster_config:
