@@ -3,7 +3,6 @@ import click
 
 
 from indico_install.infra.init import init
-from indico_install.utils import options_wrapper
 from indico_install.cluster_manager import ClusterManager
 from .setup import aks_setup, ask_for_infra_input
 from . import storage, cluster
@@ -24,13 +23,12 @@ aks.command("init")(init(__name__))
 
 @aks.command("check")
 @click.pass_context
-@options_wrapper()
-def check(ctx, *, deployment_root, **kwargs):
+def check(ctx):
     """
     Check the state of an existing cluster to validate
     that it meets certain requirements
     """
-    aks_setup(deployment_root)
+    aks_setup()
     conf = ctx.obj["TRACKER"].cluster_config
     ask_for_infra_input(conf)
     cluster.check(conf)
@@ -40,14 +38,13 @@ def check(ctx, *, deployment_root, **kwargs):
 
 @aks.command("create")
 @click.pass_context
-@options_wrapper()
-def create(ctx, upload=False, *, deployment_root, **kwargs):
+def create(ctx, upload=False):
     """
     Configure your AKS installation
     """
-    aks_setup(deployment_root)
+    aks_setup()
     conf = ctx.obj["TRACKER"].cluster_config
     ask_for_infra_input(conf)
     cluster.create(conf)
-    storage.create(deployment_root, conf)
+    storage.create(conf)
     ctx.obj["TRACKER"].save()
