@@ -41,17 +41,11 @@ def ask_for_infra_input(conf):
         type=str,
         default=conf["clusterVolumes"]["rox"]["azureFile"]["shareName"],
     )
-    default_namespace = prompt(
-        "What is the name of your default indico namespace?",
-        type=str,
-        default=conf.get("cluster", {}).get("defaultNamespace"),
-    )
     conf["cluster"].update(
         {"storage_acct": storage_acct_name, "storage_acct_key": storage_acct_key}
     )
     conf["clusterVolumes"]["rwx"]["azureFile"]["shareName"] = rwx_fs
     conf["clusterVolumes"]["rox"]["azureFile"]["shareName"] = rox_fs
-    conf["defaultNamespace"] = default_namespace
     postgres_input(conf)
 
     return conf
